# Step 2: Enrich Data
### On this page
  * [Evaluate Business Criticality and Functional Fit](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-enrich-data#evaluate-business-criticality-and-functional-fit)
  * [Link IT Components to the Reference Catalog](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-enrich-data#link-it-components-to-the-reference-catalog)
  * [Monitor Data Completeness](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-enrich-data#monitor-data-completeness)
  * [Next Step](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-enrich-data#next-step)


Enrich your data by evaluating application criticality and bringing in technology lifecycle information.
Effective obsolescence risk management requires maintaining an up-to-date IT component inventory with essential details such as lifecycle state and vendor support information. Establishing relationships between IT components and the applications they support is also crucial for aggregating risk to the business layer. SAP LeanIX simplifies technology risk management by rolling up the risks of IT components to the application level.
**Tip**
When you need to model technical platforms, we recommend using IT component fact sheets to represent them. This approach allows obsolescence risks to be aggregated to the technical platforms and subsequently to the applications. To learn more, see [Aggregating Obsolescence Risk Through Technical Platforms](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-advanced?locale=en-US&state=PRODUCTION&version=CLOUD "Use automation and SAP LeanIX Architecture and Road Map Planning to advance the obsolescence risk management use case.").
